@@ -52,7 +52,7 @@ from debian.deb822 import Deb822
 from debmutate.reformatting import FormattingUnpreservable
 
 
-__version__ = (0, 104)
+__version__ = (0, 107)
 version_string = ".".join(map(str, __version__))
 SUPPORTED_CERTAINTIES = ["certain", "confident", "likely", "possible", None]
 DEFAULT_MINIMUM_CERTAINTY = "certain"
@@ -342,7 +342,7 @@ def determine_env(
     diligence,
 ):
     env = dict(os.environ.items())
-    env["PACKAGE"] = package
+    env["DEB_SOURCE"] = package
     env["CURRENT_VERSION"] = str(current_version)
     env["COMPAT_RELEASE"] = compat_release
     env["MINIMUM_CERTAINTY"] = minimum_certainty
@@ -1274,3 +1274,25 @@ def control_files_in_root(tree: Tree, subpath: str) -> bool:
     if tree.has_filename(control_path + ".in"):
         return True
     return False
+
+
+def is_debcargo_package(tree: Tree, subpath: str) -> bool:
+    control_path = os.path.join(subpath, "debian", "debcargo.toml")
+    return tree.has_filename(control_path)
+
+
+def control_file_present(tree: Tree, subpath: str) -> bool:
+    """Check whether there are any control files present in a tree.
+
+    Args:
+      tree: Tree to check
+      subpath: subpath to check
+    Returns:
+      whether control file is present
+    """
+    for name in ["debian/control", "debian/control.in", "control",
+                 "control.in", "debian/debcargo.toml"]:
+        name = os.path.join(subpath, name)
+        if tree.has_filename(name):
+            return True
+    return False
