@@ -219,7 +219,7 @@ def diligence():
 
 
 def source_package_name():
-    return os.environ.get("PACKAGE")
+    return os.environ.get("DEB_SOURCE")
 
 
 def vendor():
@@ -231,7 +231,11 @@ def vendor():
             return c['Vendor']
 
 
-if os.path.exists('debian/debcargo.toml'):
+def is_debcargo_package():
+    return os.path.exists('debian/debcargo.toml')
+
+
+if is_debcargo_package():
     from debmutate.debcargo import DebcargoControlShimEditor, DebcargoEditor
 
     try:
